Data Association
================

.. automodule:: stonesoup.dataassociator
    :no-members:

.. automodule:: stonesoup.dataassociator.base
    :show-inheritance:

Track-to-track Association
==========================

.. automodule:: stonesoup.dataassociator.tracktotrack
    :show-inheritance:

Neighbour
---------

.. automodule:: stonesoup.dataassociator.neighbour
    :show-inheritance:

Probability
-----------

.. automodule:: stonesoup.dataassociator.probability
    :show-inheritance:
